@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,10 +17,9 @@
 
 from __future__ import division, print_function, absolute_import
 
-
 VALID_STARTS = (
-    "# coding=utf-8",
-    "#!/usr/bin/env python",
+    '# coding=utf-8',
+    '#!/usr/bin/env python',
 )
 
 if __name__ == '__main__':
@@ -28,10 +27,10 @@ if __name__ == '__main__':
     n = max(map(len, VALID_STARTS))
     bad = False
     for f in sys.argv[1:]:
-        with open(f, "r", encoding="utf-8") as i:
+        with open(f, 'r', encoding='utf-8') as i:
             start = i.read(n)
             if not any(start.startswith(s) for s in VALID_STARTS):
                 print(
-                    "%s has incorrect start %r" % (f, start), file=sys.stderr)
+                    '%s has incorrect start %r' % (f, start), file=sys.stderr)
                 bad = True
     sys.exit(int(bad))
