@@ -21,31 +21,47 @@ import os
 import warnings
 from tempfile import mkdtemp
 
-from hypothesis import settings
+from hypothesis import settings, unlimited
+from hypothesis.errors import HypothesisDeprecationWarning
 from hypothesis.configuration import set_hypothesis_home_dir
 from hypothesis.internal.charmap import charmap, charmap_file
+from hypothesis.internal.coverage import IN_COVERAGE_TESTS
 
 
 def run():
-    warnings.filterwarnings(u'error', category=UnicodeWarning)
+    warnings.filterwarnings('error', category=UnicodeWarning)
+    warnings.filterwarnings('error', category=HypothesisDeprecationWarning)
 
     set_hypothesis_home_dir(mkdtemp())
 
     charmap()
-    assert os.path.exists(charmap_file())
+    assert os.path.exists(charmap_file()), charmap_file()
     assert isinstance(settings, type)
 
-    settings.register_profile(
-        'default', settings(timeout=-1, strict=True)
-    )
+    # We do a smoke test here before we mess around with settings.
+    x = settings()
+
+    import hypothesis._settings as settings_module
+
+    for s in settings_module.all_settings.values():
+        v = getattr(x, s.name)
+        # Check if it has a dynamically defined default and if so skip
+        # comparison.
+        if getattr(settings, s.name).show_default:
+            assert v == s.default, '%r == x.%s != s.%s == %r' % (
+                v, s.name, s.name, s.default,
+            )
+
+    settings.register_profile('default', settings(
+        timeout=unlimited, use_coverage=not IN_COVERAGE_TESTS))
+
+    settings.register_profile('with_coverage', settings(
+        timeout=unlimited, use_coverage=True,
+    ))
 
     settings.register_profile(
         'speedy', settings(
-            timeout=1, max_examples=5,
+            max_examples=5,
         ))
 
-    settings.register_profile(
-        'nonstrict', settings(strict=False)
-    )
-
     settings.load_profile(os.getenv('HYPOTHESIS_PROFILE', 'default'))
