@@ -21,8 +21,6 @@ import os
 import sys
 import unicodedata
 
-import pytest
-
 import hypothesis.strategies as st
 import hypothesis.internal.charmap as cm
 from hypothesis import given, assume
@@ -111,14 +109,29 @@ def test_recreate_charmap():
 
 
 def test_union_empty():
-    assert cm._union_interval_lists([], [[1, 2]]) == [[1, 2]]
-    assert cm._union_interval_lists([[1, 2]], []) == [[1, 2]]
+    assert cm._union_intervals([], []) == ()
+    assert cm._union_intervals([], [[1, 2]]) == ((1, 2),)
+    assert cm._union_intervals([[1, 2]], []) == ((1, 2),)
+
+
+def test_union_handles_totally_overlapped_gap():
+    #   < xx  >  Imagine the intervals x and y as bit strings.
+    # | <yy yy>  The bit at position n is set if n falls inside that interval.
+    # = <zzzzz>  In this model _union_intervals() performs bit-wise or.
+    assert cm._union_intervals([[2, 3]], [[1, 2], [4, 5]]) == ((1, 5),)
+
+
+def test_union_handles_partially_overlapped_gap():
+    #   <  x  >  Imagine the intervals x and y as bit strings.
+    # | <yy  y>  The bit at position n is set if n falls inside that interval.
+    # = <zzz z>  In this model _union_intervals() performs bit-wise or.
+    assert cm._union_intervals([[3, 3]], [[1, 2], [5, 5]]) == ((1, 3), (5, 5))
 
 
 def test_successive_union():
     x = []
     for v in cm.charmap().values():
-        x = cm._union_interval_lists(x, v)
+        x = cm._union_intervals(x, v)
     assert x == ((0, sys.maxunicode),)
 
 
@@ -138,8 +151,21 @@ def test_exception_in_write_does_not_lead_to_broken_charmap(monkeypatch):
     cm._charmap = None
     monkeypatch.setattr(os.path, 'exists', lambda p: False)
     monkeypatch.setattr(os, 'rename', broken)
-    with pytest.raises(ValueError):
-        cm.charmap()
 
-    with pytest.raises(ValueError):
-        cm.charmap()
+    cm.charmap()
+    cm.charmap()
+
+
+def test_regenerate_broken_charmap_file():
+    cm.charmap()
+    file_loc = cm.charmap_file()
+
+    with open(file_loc, 'wb'):
+        pass
+
+    cm._charmap = None
+    cm.charmap()
+
+
+def test_exclude_characters_are_included_in_key():
+    assert cm.query() != cm.query(exclude_characters='0')
