@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -20,10 +20,10 @@ from __future__ import division, print_function, absolute_import
 import pytest
 
 from hypothesis.errors import CleanupFailed, InvalidArgument
-from hypothesis.control import note, event, cleanup, BuildContext, \
+from hypothesis.control import BuildContext, note, event, cleanup, \
     current_build_context, _current_build_context
 from tests.common.utils import capture_out
-from hypothesis.internal.conjecture.data import TestData as TD
+from hypothesis.internal.conjecture.data import ConjectureData as TD
 
 
 def bc():
