@@ -24,7 +24,9 @@ from flaky import flaky
 
 import hypothesis.strategies as s
 from hypothesis import find, given, reject, settings
+from hypothesis.core import arc
 from hypothesis.errors import NoSuchExample, Unsatisfiable
+from tests.common.utils import checks_deprecated_behaviour
 
 
 def test_stops_after_max_examples_if_satisfying():
@@ -64,6 +66,7 @@ def test_stops_after_max_iterations_if_not_satisfying():
     assert len(tracker) <= max_iterations
 
 
+@checks_deprecated_behaviour
 @flaky(min_passes=1, max_runs=2)
 def test_can_time_out_in_simplify():
     def slow_always_true(x):
@@ -92,7 +95,5 @@ def test_settings_are_default_in_given(x):
     assert settings.default is some_normal_settings
 
 
-def test_settings_are_default_in_find():
-    find(
-        s.booleans(), lambda x: settings.default is some_normal_settings,
-        settings=some_normal_settings)
+def test_arc_is_memoized():
+    assert arc('foo', 1, 2) is arc('foo', 1, 2)
