@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -23,7 +23,7 @@ from unittest import TestCase
 import pytest
 
 from hypothesis import given, example
-from hypothesis.executors import TestRunner
+from hypothesis.executors import ConjectureRunner
 from hypothesis.strategies import booleans, integers
 
 
@@ -91,7 +91,7 @@ def test_no_boom_on_example():
     Valueless().test_no_boom_on_example()
 
 
-class TestNormal(TestRunner, TestCase):
+class TestNormal(ConjectureRunner, TestCase):
 
     @given(booleans())
     def test_stuff(self, b):
