@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -21,7 +21,7 @@ from unittest import TestCase
 
 import pytest
 
-from hypothesis import note, given, example, settings, reporting
+from hypothesis import Verbosity, note, given, example, settings, reporting
 from hypothesis.errors import InvalidArgument
 from tests.common.utils import capture_out
 from hypothesis.strategies import text, integers
@@ -162,6 +162,20 @@ def test_prints_output_for_explicit_examples():
     assert u'Falsifying example: test_positive(x=-1)' in out
 
 
+def test_prints_verbose_output_for_explicit_examples():
+    @settings(verbosity=Verbosity.verbose)
+    @example('NOT AN INTEGER')
+    @given(integers())
+    def test_always_passes(x):
+        pass
+
+    with reporting.with_reporter(reporting.default):
+        with capture_out() as out:
+            test_always_passes()
+    out = out.getvalue()
+    assert u"Trying example: test_always_passes(x='NOT AN INTEGER')" in out
+
+
 def test_captures_original_repr_of_example():
     @example(x=[])
     @given(integers())
