@@ -31,7 +31,7 @@ OrderedPairs = integers(1, 200).flatmap(
     lambda e: tuples(integers(0, e - 1), just(e))
 )
 
-with settings(max_examples=200):
+with settings(max_examples=100):
     @given(ConstantLists)
     def test_constant_lists_are_constant(x):
         assume(len(x) >= 3)
@@ -104,3 +104,13 @@ def test_can_shrink_through_a_binding(n):
     assert find(
         bool_lists, lambda x: len(list(filter(bool, x))) >= n
     ) == [True] * n
+
+
+@pytest.mark.parametrize('n', range(1, 10))
+def test_can_delete_in_middle_of_a_binding(n):
+    bool_lists = integers(1, 100).flatmap(
+        lambda k: lists(booleans(), min_size=k, max_size=k))
+
+    assert find(
+        bool_lists, lambda x: x[0] and x[-1] and x.count(False) >= n
+    ) == [True] + [False] * n + [True]
