@@ -19,16 +19,24 @@ from __future__ import division, print_function, absolute_import
 
 from hypothesis import strategies as st
 from hypothesis import find, note, given, settings
+from tests.common.utils import checks_deprecated_behaviour
 
 
-@given(st.streaming(st.integers(min_value=0)), st.random_module())
-@settings(buffer_size=200, max_shrinks=5, max_examples=10)
-def test_can_eval_stream_inside_find(stream, rnd):
-    x = find(
-        st.lists(st.integers(min_value=0), min_size=10),
-        lambda t: any(t > s for (t, s) in zip(t, stream)),
-        settings=settings(database=None, max_shrinks=2000, max_examples=2000)
-    )
-    note('x: %r' % (x,))
-    note('Evalled: %r' % (stream,))
-    assert len([1 for i, v in enumerate(x) if stream[i] < v]) == 1
+@checks_deprecated_behaviour
+def test_can_eval_stream_inside_find():
+    @given(st.streaming(st.integers(min_value=0)), st.random_module())
+    @settings(
+        buffer_size=200, max_shrinks=5, max_examples=10,
+        perform_health_check=False)
+    def test(stream, rnd):
+        x = find(
+            st.lists(st.integers(min_value=0), min_size=10),
+            lambda t: any(t > s for (t, s) in zip(t, stream)),
+            settings=settings(
+                database=None, max_shrinks=2000, max_examples=2000)
+        )
+        note('x: %r' % (x,))
+        note('Evalled: %r' % (stream,))
+        assert len([1 for i, v in enumerate(x) if stream[i] < v]) == 1
+
+    test()
