@@ -22,11 +22,15 @@ from tempfile import mkdtemp
 
 import pytest
 
-import hypothesis
-from hypothesis.errors import InvalidState, InvalidArgument
+import hypothesis.strategies as st
+from hypothesis import given, unlimited
+from hypothesis.errors import InvalidState, InvalidArgument, \
+    HypothesisDeprecationWarning
+from tests.common.utils import checks_deprecated_behaviour
 from hypothesis.database import ExampleDatabase, \
     DirectoryBasedExampleDatabase
-from hypothesis._settings import Verbosity, settings, note_deprecation
+from hypothesis._settings import Verbosity, settings, default_variable, \
+    note_deprecation
 
 
 def test_has_docstrings():
@@ -118,9 +122,15 @@ def test_can_assign_database(db):
     assert x.database is db
 
 
+def test_will_reload_profile_when_default_is_absent():
+    original = settings.default
+    default_variable.value = None
+    assert settings.default is original
+
+
 def test_load_profile():
     settings.load_profile('default')
-    assert settings.default.max_examples == 200
+    assert settings.default.max_examples == 100
     assert settings.default.max_shrinks == 500
     assert settings.default.min_satisfying_examples == 5
 
@@ -140,7 +150,7 @@ def test_load_profile():
 
     settings.load_profile('default')
 
-    assert settings.default.max_examples == 200
+    assert settings.default.max_examples == 100
     assert settings.default.max_shrinks == 500
     assert settings.default.min_satisfying_examples == 5
 
@@ -155,7 +165,7 @@ def test_loading_profile_keeps_expected_behaviour():
 
 
 def test_load_non_existent_profile():
-    with pytest.raises(hypothesis.errors.InvalidArgument):
+    with pytest.raises(InvalidArgument):
         settings.get_profile('nonsense')
 
 
@@ -163,7 +173,6 @@ def test_load_non_existent_profile():
     os.getenv('HYPOTHESIS_PROFILE') not in (None, 'default'),
     reason='Defaults have been overridden')
 def test_runs_tests_with_defaults_from_conftest():
-    assert settings.default.strict
     assert settings.default.timeout == -1
 
 
@@ -178,13 +187,18 @@ def test_cannot_delete_a_setting():
         del x.foo
 
 
-def test_deprecate_uses_default():
-    with settings(strict=False):
-        note_deprecation('Hi')
+def test_cannot_set_strict():
+    with pytest.raises(HypothesisDeprecationWarning):
+        settings(strict=True)
 
-    with settings(strict=True):
-        with pytest.raises(DeprecationWarning):
-            note_deprecation('Hi')
+
+@checks_deprecated_behaviour
+def test_set_deprecated_settings():
+    assert settings(timeout=3).timeout == 3
+
+
+def test_setting_to_future_value_gives_future_value_and_no_error():
+    assert settings(timeout=unlimited).timeout == -1
 
 
 def test_cannot_set_settings():
@@ -225,6 +239,11 @@ def test_cannot_assign_default():
 
 def test_does_not_warn_if_quiet():
     with pytest.warns(None) as rec:
-        note_deprecation('This is bad', settings(
-            strict=False, verbosity=Verbosity.quiet))
+        note_deprecation('This is bad', settings(verbosity=Verbosity.quiet))
     assert len(rec) == 0
+
+
+@settings(max_examples=7)
+@given(st.builds(lambda: settings.default))
+def test_settings_in_strategies_are_from_test_scope(s):
+    assert s.max_examples == 7
