@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -121,6 +121,6 @@ def test_can_restrict_to_ascii_only(s):
 
 
 def test_fixed_size_bytes_just_draw_bytes():
-    from hypothesis.internal.conjecture.data import TestData
-    x = TestData.for_buffer(b'foo')
+    from hypothesis.internal.conjecture.data import ConjectureData
+    x = ConjectureData.for_buffer(b'foo')
     assert x.draw(binary(min_size=3, max_size=3)) == b'foo'
