@@ -17,8 +17,10 @@
 
 from __future__ import division, print_function, absolute_import
 
+import pytest
+
 import hypothesis.strategies as st
-from hypothesis import find, given
+from hypothesis import find, given, settings
 
 
 @given(st.lists(st.uuids()))
@@ -26,7 +28,17 @@ def test_are_unique(ls):
     assert len(set(ls)) == len(ls)
 
 
+@settings(deadline=None)
 @given(st.lists(st.uuids()), st.randoms())
 def test_retains_uniqueness_in_simplify(ls, rnd):
     ts = find(st.lists(st.uuids()), lambda x: len(x) >= 5, random=rnd)
     assert len(ts) == len(set(ts)) == 5
+
+
+@pytest.mark.parametrize('version', (1, 2, 3, 4, 5))
+def test_can_generate_specified_version(version):
+    @given(st.uuids(version=version))
+    def inner(uuid):
+        assert version == uuid.version
+
+    inner()
