@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2016 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -70,9 +70,9 @@ MIDDLEWARE_CLASSES = (
     u'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
 
-ROOT_URLCONF = u'toys.urls'
+ROOT_URLCONF = u'tests.django.toys.urls'
 
-WSGI_APPLICATION = u'toys.wsgi.application'
+WSGI_APPLICATION = u'tests.django.toys.wsgi.application'
 
 
 # Database
@@ -96,7 +96,7 @@ USE_I18N = True
 
 USE_L10N = True
 
-USE_TZ = True
+USE_TZ = os.environ.get('HYPOTHESIS_DJANGO_USETZ', 'TRUE') == 'TRUE'
 
 
 # Static files (CSS, JavaScript, Images)
