@@ -20,10 +20,12 @@ from __future__ import division, print_function, absolute_import
 from django.contrib import admin
 from django.conf.urls import url, include
 
+patterns, namespace, name = admin.site.urls
+
 urlpatterns = [
     # Examples:
     # url(r'^$', 'toys.views.home', name='home'),
     # url(r'^blog/', include('blog.urls')),
 
-    url(r'^admin/', include(admin.site.urls)),
+    url(r'^admin/', include((patterns, name), namespace=namespace))
 ]
