@@ -17,15 +17,16 @@
 
 from __future__ import division, print_function, absolute_import
 
-import sys
 import inspect
+import warnings
 
 import pytest
 
 from hypothesis import strategies as st
 from hypothesis import given
-from hypothesis.internal.compat import FullArgSpec, hrange, qualname, \
-    int_to_bytes, getfullargspec, int_from_bytes
+from hypothesis.internal.compat import FullArgSpec, ceil, floor, hrange, \
+    qualname, int_to_bytes, integer_types, getfullargspec, \
+    int_from_bytes
 
 
 def test_small_hrange():
@@ -73,7 +74,9 @@ def d(a1, a2=1, a3=2, a4=None):
 
 @pytest.mark.parametrize('f', [a, b, c, d])
 def test_agrees_on_argspec(f):
-    basic = inspect.getargspec(f)
+    with warnings.catch_warnings():
+        warnings.simplefilter('ignore', DeprecationWarning)
+        basic = inspect.getargspec(f)
     full = getfullargspec(f)
     assert basic.args == full.args
     assert basic.varargs == full.varargs
@@ -105,13 +108,32 @@ def test_to_bytes_in_big_endian_order(x, y):
     assert int_to_bytes(x, 8) <= int_to_bytes(y, 8)
 
 
-@pytest.mark.skipif(sys.version_info[0] != 3 or sys.version_info[:2] == (3, 5),
-                    reason='getfullargspec was deprecated, so we wrap it')
+@pytest.mark.skipif(not hasattr(inspect, 'getfullargspec'),
+                    reason='inspect.getfullargspec only exists under Python 3')
 def test_inspection_compat():
     assert getfullargspec is inspect.getfullargspec
 
 
-@pytest.mark.skipif(sys.version_info[0] != 3,
+@pytest.mark.skipif(not hasattr(inspect, 'FullArgSpec'),
                     reason='inspect.FullArgSpec only exists under Python 3')
 def test_inspection_result_compat():
     assert FullArgSpec is inspect.FullArgSpec
+
+
+@given(st.fractions())
+def test_ceil(x):
+    """The compat ceil function always has the Python 3 semantics.
+
+    Under Python 2, math.ceil returns a float, which cannot represent large
+    integers - for example, `float(2**53) == float(2**53 + 1)` - and this
+    is obviously incorrect for unlimited-precision integer operations.
+
+    """
+    assert isinstance(ceil(x), integer_types)
+    assert x <= ceil(x) < x + 1
+
+
+@given(st.fractions())
+def test_floor(x):
+    assert isinstance(floor(x), integer_types)
+    assert x - 1 < floor(x) <= x
