@@ -21,11 +21,11 @@ import math
 import hashlib
 from random import Random
 
-from hypothesis import Verbosity, seed, given, assume, settings
-from hypothesis.errors import NoExamples, FailedHealthCheck
+from hypothesis import Verbosity, seed, given, assume, settings, unlimited
+from hypothesis.errors import FailedHealthCheck
 from hypothesis.database import ExampleDatabase
 from hypothesis.stateful import Bundle, RuleBasedStateMachine, rule
-from hypothesis.strategies import just, none, text, lists, binary, \
+from hypothesis.strategies import data, just, none, text, lists, binary, \
     floats, tuples, booleans, decimals, integers, fractions, \
     float_to_int, int_to_float, sampled_from, complex_numbers
 from hypothesis.internal.compat import PYPY
@@ -145,9 +145,9 @@ class HypothesisSpec(RuleBasedStateMachine):
     def list_strategy(self, elements):
         return lists(elements, average_size=AVERAGE_LIST_LENGTH)
 
-    @rule(target=strategies, l=strategies, r=strategies)
-    def or_strategy(self, l, r):
-        return l | r
+    @rule(target=strategies, left=strategies, right=strategies)
+    def or_strategy(self, left, right):
+        return left | right
 
     @rule(target=varied_floats, source=floats())
     def float(self, source):
@@ -201,18 +201,13 @@ class HypothesisSpec(RuleBasedStateMachine):
     def single_tuple(self, source):
         return (source,)
 
-    @rule(target=strategy_tuples, l=strategy_tuples, r=strategy_tuples)
-    def cat_tuples(self, l, r):
-        return l + r
+    @rule(target=strategy_tuples, left=strategy_tuples, right=strategy_tuples)
+    def cat_tuples(self, left, right):
+        return left + right
 
-    @rule(target=objects, strat=strategies)
-    def get_example(self, strat):
-        try:
-            strat.example()
-        except NoExamples:
-            # Because of filtering some strategies we look for don't actually
-            # have any examples.
-            pass
+    @rule(target=objects, strat=strategies, data=data())
+    def get_example(self, strat, data):
+        data.draw(strat)
 
     @rule(target=strategies, left=integers(), right=integers())
     def integer_range(self, left, right):
@@ -232,11 +227,10 @@ TestHypothesis.settings = settings(
     TestHypothesis.settings,
     stateful_step_count=10 if PYPY else 50,
     max_shrinks=500,
-    timeout=500 if MAIN else 60,
+    timeout=unlimited,
     min_satisfying_examples=0,
     verbosity=max(TestHypothesis.settings.verbosity, Verbosity.verbose),
     max_examples=10000 if MAIN else 200,
-    strict=True
 )
 
 if MAIN:
