@@ -26,6 +26,10 @@ TESTSUITE = """
 from hypothesis import given, settings, assume
 from hypothesis.strategies import integers
 import time
+import warnings
+from hypothesis.errors import HypothesisDeprecationWarning
+
+warnings.simplefilter('always', HypothesisDeprecationWarning)
 
 
 @given(integers())
@@ -39,7 +43,9 @@ def test_slow(x):
     time.sleep(0.1)
 
 
-@settings(max_examples=1000, min_satisfying_examples=1)
+@settings(
+    max_examples=1000, min_satisfying_examples=1, perform_health_check=False
+)
 @given(integers())
 def test_iterations(x):
     assume(x % 50 == 0)
@@ -59,8 +65,9 @@ def test_prints_statistics_given_option(testdir):
     out = '\n'.join(result.stdout.lines)
     assert 'Hypothesis Statistics' in out
     assert 'timeout=0.2' in out
-    assert 'max_examples=200' in out
+    assert 'max_examples=100' in out
     assert 'max_iterations=1000' in out
+    assert 'HypothesisDeprecationWarning' in out
 
 
 UNITTEST_TESTSUITE = """
@@ -83,7 +90,7 @@ def test_prints_statistics_for_unittest_tests(testdir):
     out = '\n'.join(result.stdout.lines)
     assert 'Hypothesis Statistics' in out
     assert 'TestStuff::test_all_valid' in out
-    assert 'max_examples=200' in out
+    assert 'max_examples=100' in out
 
 
 STATEFUL_TESTSUITE = """
@@ -110,4 +117,4 @@ def test_prints_statistics_for_stateful_tests(testdir):
     out = '\n'.join(result.stdout.lines)
     assert 'Hypothesis Statistics' in out
     assert 'TestStuff::runTest' in out
-    assert 'max_examples=200' in out
+    assert 'max_examples=100' in out
